MethodChannelCcid class

An implementation of CcidPlatform that uses method channels.

Inheritance

Constructors

MethodChannelCcid()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(String reader) → Future<CcidCard>
override
disconnect(String reader) → Future<void>
override
listReaders() → Future<List<String>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transceive(String reader, String capdu) → Future<String?>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited