CcidPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • CcidPlatform
Implementers

Constructors

CcidPlatform()
Constructs a CcidPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(String reader) → Future<CcidCard>
disconnect(String reader) → Future<void>
listReaders() → Future<List<String>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transceive(String reader, String capdu) → Future<String?>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → CcidPlatform
The default instance of CcidPlatform to use.
no setter